@@ -8,11 +8,10 @@ use 5.014;
 
 use parent 'Class::Accessor';
 use DateTime::Format::Strptime;
-use List::Util   qw(any);
-use Scalar::Util qw(weaken);
+use List::Util qw(any);
 use Travel::Status::DE::HAFAS::Stop;
 
-our $VERSION = '5.01';
+our $VERSION = '5.02';
 
 Travel::Status::DE::HAFAS::Journey->mk_ro_accessors(
 	qw(datetime sched_datetime rt_datetime
@@ -120,8 +119,6 @@ sub new {
 			datetime_ref => $datetime_ref,
 		};
 
-		weaken( $stopref->{hafas} );
-
 		push( @stops, $stopref );
 
 		$route_end = $loc->name;
@@ -403,7 +400,7 @@ journey received by Travel::Status::DE::HAFAS
 
 =head1 VERSION
 
-version 5.01
+version 5.02
 
 =head1 DESCRIPTION
 
